
# Type: child of named thing_subject




URI: [https://example.com/test65/child_of_named_thing_subject](https://example.com/test65/child_of_named_thing_subject)


## Domain and Range

[ChildOfNamedThing](ChildOfNamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [ChildOfNamedThing](ChildOfNamedThing.md)
